@@ -11,26 +11,32 @@ __all__ = ['GraphSyntax', 'DigraphSyntax', 'Dot']
 
 
 def comment(line: str):
+    """Return comment header line."""
     return f'// {line}\n'
 
 
 def graph_head(name: str) -> str:
+    """Return DOT graph head line."""
     return f'graph {name}{{\n'
 
 
 def digraph_head(name: str) -> str:
+    """Return DOT digraph head line."""
     return f'digraph {name}{{\n'
 
 
 def graph_edge(*, tail: str, head: str, attr: str) -> str:
+    """Return DOT graph edge statement line."""
     return f'\t{tail} -- {head}{attr}\n'
 
 
 def digraph_edge(*, tail: str, head: str, attr: str) -> str:
+    """Return DOT digraph edge statement line."""
     return f'\t{tail} -> {head}{attr}\n'
 
 
 class GraphSyntax:
+    """DOT graph head and edge syntax."""
 
     _head = staticmethod(graph_head)
 
@@ -38,6 +44,7 @@ class GraphSyntax:
 
 
 class DigraphSyntax:
+    """DOT digraph head and edge syntax."""
 
     _head = staticmethod(digraph_head)
 
@@ -45,19 +52,22 @@ class DigraphSyntax:
 
 
 def subgraph(name: str) -> str:
+    """Return DOT subgraph head line."""
     return f'subgraph {name}{{\n'
 
 
 def subgraph_plain(name: str) -> str:
+    """Return plain DOT subgraph head line."""
     return f'{name}{{\n'
 
 
 def node(left: str, right: str) -> str:
+    """Return DOT node statement line."""
     return f'\t{left}{right}\n'
 
 
 class Dot(quoting.Quote, base.Base):
-    """Assemble, save, and render DOT source code, open result in viewer."""
+    """Assemble DOT source code."""
 
     directed: bool
 
@@ -65,10 +75,12 @@ class Dot(quoting.Quote, base.Base):
 
     @staticmethod
     def _head(name: str) -> str:  # pragma: no cover
+        """Return DOT head line."""
         raise NotImplementedError('must be implemented by concrete subclasses')
 
     @classmethod
     def _head_strict(cls, name: str) -> str:
+        """Return DOT strict head line."""
         return f'strict {cls._head(name)}'
 
     _tail = '}\n'
@@ -85,10 +97,12 @@ class Dot(quoting.Quote, base.Base):
 
     @staticmethod
     def _edge(*, tail: str, head: str, attr: str) -> str:  # pragma: no cover
+        """Return DOT edge statement line."""
         raise NotImplementedError('must be implemented by concrete subclasses')
 
     @classmethod
     def _edge_plain(cls, *, tail: str, head: str) -> str:
+        """Return plain DOT edge statement line."""
         return cls._edge(tail=tail, head=head, attr='')
 
     def __init__(self, *,
@@ -139,7 +153,7 @@ class Dot(quoting.Quote, base.Base):
         if not keep_attrs:
             for a in (self.graph_attr, self.node_attr, self.edge_attr):
                 a.clear()
-        del self.body[:]
+        self.body.clear()
 
     @_tools.deprecate_positional_args(supported_number=1)
     def __iter__(self, subgraph: bool = False) -> typing.Iterator[str]:
@@ -163,8 +177,7 @@ class Dot(quoting.Quote, base.Base):
             if attrs:
                 yield self._attr(kw, self._attr_list(None, kwargs=attrs))
 
-        for line in self.body:
-            yield line
+        yield from self.body
 
         yield self._tail
 
@@ -226,8 +239,8 @@ class Dot(quoting.Quote, base.Base):
         """
         edge = self._edge_plain
         quote = self._quote_edge
-        lines = (edge(tail=quote(t), head=quote(h)) for t, h in tail_head_iter)
-        self.body.extend(lines)
+        self.body += [edge(tail=quote(t), head=quote(h))
+                      for t, h in tail_head_iter]
 
     @_tools.deprecate_positional_args(supported_number=2)
     def attr(self, kw: typing.Optional[str] = None,
@@ -301,12 +314,12 @@ class Dot(quoting.Quote, base.Base):
             subgraph = self.__class__(**kwargs)
 
             @contextlib.contextmanager
-            def subgraph_contextmanager():
-                """Return subgraph and add to self on exit."""
+            def subgraph_contextmanager(*, parent):
+                """Return subgraph and add to parent on exit."""
                 yield subgraph
-                self.subgraph(subgraph)
+                parent.subgraph(subgraph)
 
-            return subgraph_contextmanager()
+            return subgraph_contextmanager(parent=self)
 
         args = [name, comment, graph_attr, node_attr, edge_attr, body]
         if not all(a is None for a in args):
@@ -316,5 +329,4 @@ class Dot(quoting.Quote, base.Base):
             raise ValueError(f'{self!r} cannot add subgraph of different kind:'
                              f' {graph!r}')
 
-        lines = ['\t' + line for line in graph.__iter__(subgraph=True)]
-        self.body.extend(lines)
+        self.body += [f'\t{line}' for line in graph.__iter__(subgraph=True)]
